@@ -28,6 +28,12 @@
 
 #define MAX_PLAYER_ICONS 8
 
+#ifdef CATEGORY_FILE
+#define CATEGORY_FACTORY_FUNC columns_factory_category
+#else
+#define CATEGORY_FACTORY_FUNC NULL
+#endif
+
 typedef GtkTreeViewColumn * (*FactoryFunc) (GvaGameStoreColumn);
 
 static GdkPixbuf *
@@ -166,6 +172,26 @@ columns_sampleset_set_properties (GtkTreeViewColumn *column,
         g_free (sampleset);
 }
 
+static GtkTreeViewColumn *
+columns_factory_category (GvaGameStoreColumn column_id)
+{
+        GtkTreeViewColumn *column;
+        GtkCellRenderer *renderer;
+
+        column = gtk_tree_view_column_new ();
+        gtk_tree_view_column_set_reorderable (column, TRUE);
+        gtk_tree_view_column_set_sort_column_id (column, column_id);
+        gtk_tree_view_column_set_title (column, _("Category"));
+
+        renderer = gtk_cell_renderer_text_new ();
+        gtk_tree_view_column_pack_start (column, renderer, TRUE);
+
+        gtk_tree_view_column_add_attribute (
+                column, renderer, "text", column_id);
+
+        return column;
+}
+
 static GtkTreeViewColumn *
 columns_factory_description (GvaGameStoreColumn column_id)
 {
@@ -391,6 +417,7 @@ static struct
 column_info[GVA_GAME_STORE_NUM_COLUMNS] =
 {
         { "name",               columns_factory_name },
+        { "category",           CATEGORY_FACTORY_FUNC },
         { "favorite",           columns_factory_favorite },
         { "sourcefile",         columns_factory_sourcefile },
         { "runnable",           NULL },
@@ -427,6 +454,9 @@ static gchar *default_column_order[] =
         "description",
         "year",
         "manufacturer",
+#ifdef CATEGORY_FILE
+        "category",
+#endif
         "driver_status",
         "input_players",
         "name",
@@ -524,7 +554,7 @@ const gchar *
 gva_columns_lookup_name (GvaGameStoreColumn column_id)
 {
         if (CLAMP (column_id, 0, G_N_ELEMENTS (column_info)) != column_id)
-                return FALSE;
+                return NULL;
 
         return column_info[column_id].name;
 }
